<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MX Remastercc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>Persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;This tool allows you to rework an ISO while running Live. &lt;/span&gt;&lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Remaster&lt;/span&gt; allows you to change files, applications and settings with the goal of producing a new master copy for storage or distribution. &lt;/p&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Persistence&lt;/span&gt; allows you to retain data, settings and installed programs when the machine gets switched off for personal use.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="133"/>
        <source>Display help </source>
        <translation type="unfinished">Көмекті көрсету</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="136"/>
        <source>Help</source>
        <translation type="unfinished">Көмек</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="143"/>
        <source>Alt+H</source>
        <translation type="unfinished">Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="175"/>
        <source>About this application</source>
        <translation type="unfinished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="178"/>
        <source>About...</source>
        <translation type="unfinished">Осы туралы...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Alt+B</source>
        <translation type="unfinished">Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>Quit application</source>
        <translation type="unfinished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Close</source>
        <translation type="unfinished">Жабу</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Alt+N</source>
        <translation type="unfinished">Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Basic operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="274"/>
        <source>Remaster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Save root persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600; text-decoration: underline;&quot;&gt;Optional operations&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <source>Configure live persistence</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="54"/>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>About MX Remaster Control Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="97"/>
        <source>Version: </source>
        <translation type="unfinished">Нұсқасы:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="98"/>
        <source>This program provides access to different remaster and persistence tools in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>License</source>
        <translation type="unfinished">Лицензиясы</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="103"/>
        <source>Cancel</source>
        <translation type="unfinished">Бас тарту</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="119"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>mxremastercc</name>
    <message>
        <source>Display help </source>
        <translation type="vanished">Көмекті көрсету</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="vanished">Көмек</translation>
    </message>
    <message>
        <source>Alt+H</source>
        <translation type="vanished">Alt+H</translation>
    </message>
    <message>
        <source>About this application</source>
        <translation type="vanished">Бұл қолданба жөнінде</translation>
    </message>
    <message>
        <source>About...</source>
        <translation type="vanished">Осы туралы...</translation>
    </message>
    <message>
        <source>Alt+B</source>
        <translation type="vanished">Alt+B</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="vanished">Қолданба жұмысын аяқтау</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">Жабу</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation type="vanished">Alt+N</translation>
    </message>
    <message>
        <source>Version: </source>
        <translation type="vanished">Нұсқасы:</translation>
    </message>
    <message>
        <source>Copyright (c) MX Linux</source>
        <translation type="vanished">Copyright (c) MX Linux</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Лицензиясы</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Бас тарту</translation>
    </message>
</context>
</TS>
